@@ -1,7 +1,7 @@
 import pandas as pd
 from tqdm.autonotebook import tqdm 
 import matplotlib.pyplot as plt
-from .graph_show import GraphShow
+#from .graph_show import GraphShow
 import networkx as nx
 from operator import itemgetter
 import warnings 
@@ -151,6 +151,7 @@ def _index_generator(file_name):
     L=[]
     for i in range(len(color)):
         L.append(i*3) #i's use for the separation between nodes
+    fig = plt.figure(1, figsize=(5, 3))
     plt.scatter(L, [1  for x in range(len(color))], s = 2000/len(L), color = color, marker = 'D')
     plt.xlim(-1, (len(color)-1)*3+1)
     plt.ylim(0.5, 1.5)
@@ -222,8 +223,7 @@ def _index_generator(file_name):
             label_number_upper([L[i],1], Group[L[i]//3][:], color1[i])
 
     # Saving and adjusting the size
-    plt.title('Index for the graph: ' + name_graph, color = "grey")
-    plt.savefig(file_name + '.png')
+    plt.savefig(file_name + '.png', dpi = 50)
     plt.close
     
     legend = file_name + '.png'
